summaryrefslogtreecommitdiffstats
path: root/sys/isa/isa_common.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/isa/isa_common.c')
-rw-r--r--sys/isa/isa_common.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/isa/isa_common.c b/sys/isa/isa_common.c
index 162d375..2d5a866 100644
--- a/sys/isa/isa_common.c
+++ b/sys/isa/isa_common.c
@@ -1105,10 +1105,10 @@ static driver_t isa_driver = {
};
/*
* ISA can be attached to a PCI-ISA bridge or directly to the nexus.
*/
DRIVER_MODULE(isa, isab, isa_driver, isa_devclass, 0, 0);
DRIVER_MODULE(isa, eisab, isa_driver, isa_devclass, 0, 0);
#ifdef __i386__
-DRIVER_MODULE(isa, nexus, isa_driver, isa_devclass, 0, 0);
+DRIVER_MODULE(isa, legacy, isa_driver, isa_devclass, 0, 0);
#endif
OpenPOWER on IntegriCloud
@@ -1105,10 +1105,10 @@ static driver_t isa_driver = {
};
/*
- * ISA can be attached to a PCI-ISA bridge or directly to the nexus.
+ * ISA can be attached to a PCI-ISA bridge or directly to the legacy device.
*/
DRIVER_MODULE(isa, isab, isa_driver, isa_devclass, 0, 0);